@@ -75,7 +75,9 @@ class NotebookRunner(object):
         reply = self.shell.get_msg()
         status = reply['content']['status']
         if status == 'error':
-            logging.info('Cell raised uncaught exception: \n%s', '\n'.join(reply['content']['traceback']))
+            traceback_text = 'Cell raised uncaught exception: \n' + \
+                '\n'.join(reply['content']['traceback'])
+            logging.info(traceback_text)
         else:
             logging.info('Cell returned')
 
@@ -121,13 +123,16 @@ class NotebookRunner(object):
                 out.traceback = content['traceback']
 
                 #logging.error('\n'.join(content['traceback']))
+            elif msg_type == 'clear_output':
+                outs = list()
+                continue
             else:
                 raise NotImplementedError('unhandled iopub message: %s' % msg_type)
             outs.append(out)
         cell['outputs'] = outs
 
         if status == 'error':
-            raise NotebookError()
+            raise NotebookError(traceback_text)
 
 
     def iter_code_cells(self):
